<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://themeregion.com/
 * @since      1.0.0
 *
 * @package    Themeregion_Companion
 * @subpackage Themeregion_Companion/admin
 */

defined( 'TRC_ADMIN_PARTIALS' ) or define( 'TRC_ADMIN_PARTIALS', dirname( __FILE__ ) . '/partials/' );

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Themeregion_Companion
 * @subpackage Themeregion_Companion/admin
 * @author     ThemeRegion Team <support@themeregion.com>
 */
class Themeregion_Companion_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->load_theme_includes();

	}

	public function load_theme_includes() {

		require_once TRC_ADMIN_PARTIALS . 'post-types.php';
		require_once TRC_ADMIN_PARTIALS . 'codestar-framework/codestar-framework.php';
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/themeregion-companion-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/themeregion-companion-admin.js', array( 'jquery' ), $this->version, false );

	}

}
